import React from "react";
import { motion } from "framer-motion";

interface AnimatedWordProps {
  text: string;
  textClassName: string;
  className: string;
}

const AnimatedWord: React.FC<AnimatedWordProps> = ({
  text,
  textClassName,
  className,
}) => {
  const words = text.split(" ");

  const container = {
    hidden: { opacity: 0 },
    visible: {
      opacity: 1,
      transition: { staggerChildren: 0.12, delayChildren: 0.04 },
    },
  };
  const child = {
    visible: {
      opacity: 1,
      y: 0,
      x: 0,
      transition: {
        type: "spring",
        damping: 12,
        stiffness: 100,
      },
    },
    hidden: {
      opacity: 0,
      y: -15,
      x: 30,
      transition: {
        type: "spring",
        damping: 12,
        stiffness: 100,
      },
    },
  };

  return (
    <motion.div
      className={className}
      variants={container}
      initial="hidden"
      animate="visible"
    >
      {words.map((word, index) => (
        <motion.span
        className={textClassName}
        key={index}
        variants={child}
        initial="hidden"
        animate="visible"
        >
          {word}
        </motion.span>
      ))}
    </motion.div>
  );
};
export default AnimatedWord;
