import mongoose, {model, Schema } from 'mongoose';
import { type Action, ActionSide, type Position } from '@finvis/usxi';

interface InterfaceUsers{
  email: string;
  username: string;
  password: string;
  apiKeys: {
    name: string;
    key: string;
    iv: string;
  }[];
  value:{
    amount: number;
    date: string;
  }[];
  balance: {
    amount: number;
    date: string;
  }[];
  trades: Action[];
  positions: Position[];
  papervalue:{
    amount: number;
    date: string;
  }[];
  paperbalance: {
    amount: number;
    date: string;
  }[];
  papertrades: Action[];
  paperpositions: Position[];
}

const userSchema = new Schema<InterfaceUsers>({
    email: {
      type: String,
      required: true,
      unique: true
    },
      username: {
      type: String,
      required: true,
      // Ensure username is unique in the dataset:
      unique: true,
    },
    password: {
      type: String,
      required: true,
    },
    apiKeys: [
      {
        name: String,
        key: String,
        iv: String,
      },
    ],
    value: [
      {
        amount: Number,
        date: String,
      }
    ],
    balance: [
      {
        amount: Number,
        date: String,
      }
    ],
    trades: [
      {
        symbol: String,
        quantity: Number,
        side: ActionSide,
        pricePerShare: Number,
        timestamp: Date,
      }
    ],
    positions: [
      {
        symbol: String,
        quantity: Number,
        marketValue: Number,
        costBasis: Number,
        pricePerShare: Number,
      }
    ],
    papervalue: [
      {
        amount: Number,
        date: String,
      }
    ],
    paperbalance: [
      {
        amount: Number,
        date: String,
      }
    ],
    papertrades: [
      {
        symbol: String,
        quantity: Number,
        side: ActionSide,
        pricePerShare: Number,
        timestamp: Date,
      }
    ],
    paperpositions: [
      {
        symbol: String,
        quantity: Number,
        marketValue: Number,
        costBasis: Number,
        pricePerShare: Number,
      }
    ],
  });

export const UserModel = model<InterfaceUsers>('users', userSchema);
